@@ -12,7 +12,7 @@ class Base(BaseEstimator, TransformerMixin):
         self.data_container_type="pandas"
         self.start_datetime = ""
         self.end_datetime = ""
-        self.breakpoint = "false"
+        self.breakpoint = 0
         self.print_task_result=0
 
 
