@@ -8,6 +8,7 @@ import re
 from cetl.functional_modules.parallel_transformer import parallelTransformer
 from cetl.utils.builder import (build_transformer_from_cfg, get_register, FUNCTIONAL_TRANSFORMERS)
 from .dot_node import update_node, recursive_build_digraph, add_dot_node, init_digraph, append_node_text
+from .file_mgt import get_datetime_str
 
 
 def _name_estimators(estimators):
@@ -72,7 +73,7 @@ def recursive_build_pipeline_from_cfg(  cfg,
     for trans_cfg in cfg["pipeline"]:
         trans_name = trans_cfg.get("type")  if "type" in trans_cfg else ""
         trans_name = "pipeline" if "pipeline" in trans_cfg else trans_name
-        breakpoint = trans_cfg.pop("breakpoint") if "breakpoint" in trans_cfg else "false"
+        breakpoint = trans_cfg.pop("breakpoint") if "breakpoint" in trans_cfg else 0
 
         
         if trans_name == "parallelTransformer":         
@@ -108,7 +109,7 @@ def recursive_build_pipeline_from_cfg(  cfg,
 
                     #add note pair
                     index = index + 1
-                    sub_breakpoint = sub_trans_cfg.pop("breakpoint") if "breakpoint" in sub_trans_cfg else "false"
+                    sub_breakpoint = sub_trans_cfg.pop("breakpoint") if "breakpoint" in sub_trans_cfg else 0
                     description = sub_trans_cfg.pop("description") if "description" in sub_trans_cfg else ""
                     module_type = trans_cfg.pop("module_type") if "module_type" in sub_trans_cfg else ""
                     TRANSFORMERS = get_register(module_type)
@@ -181,7 +182,7 @@ def recursive_build_pipeline_from_cfg(  cfg,
         else:
             index = index + 1
             node_name = f"{str(index)}.{trans_name}"
-            # breakpoint=trans_cfg.pop("breakpoint") if "breakpoint" in trans_cfg else "false"
+            # breakpoint=trans_cfg.pop("breakpoint") if "breakpoint" in trans_cfg else 0
             description = trans_cfg.pop("description") if "description" in trans_cfg else ""
             module_type = trans_cfg.pop("module_type") if "module_type" in trans_cfg else ""
             TRANSFORMERS = get_register(module_type)
@@ -289,9 +290,10 @@ class Pipeline(sklearn_pipeline):
         for _, _, transformer in self._iter():
             Xt = transformer.transform(Xt)
             if hasattr(transformer, "breakpoint"):
-                if transformer.breakpoint=="true":
+                if transformer.breakpoint:
                     # print(transform.node_name, "has breakpoint", transform.breakpoint)
-                    print(f"stop with breakpoint at {transformer.node_name}") if transformer.print_task_result else ""
+                    datetime_str = get_datetime_str(format="%Y-%m-%d %H:%M:%S")
+                    print(f"{datetime_str} stop with breakpoint at {transformer.node_name}") if transformer.print_task_result else ""
                     return Xt
         return Xt
     
@@ -368,9 +370,6 @@ class DataPipeline:
         # self.transport.close()
         pass
 
-    def build_pipeline_from_steps(self):
-        pass
-
     def build_pipeline_from_cfg(self):
 
         
